@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, version 2 of the License.
@@ -13,8 +11,13 @@
 
 # How long to wait for the server send data before giving up, as a float
 # or a (connect timeout, read timeout) tuple.
-# Default value from requests library is 3
-TIMEOUT_HTTP_PROTOCOL = 3.0
+# requests library suggests a value slightly larger than a multiple of 3.
+TIMEOUT_HTTP_PROTOCOL = 6.05
+
+# Socket TCP keep alive parameters.
+KEEPALIVE_IDLE = 20
+KEEPALIVE_INTERVAL = 10
+KEEPALIVE_COUNT = 5
 
 # Retries - maximum number of retries each connection should attempt
 # Default value from requests library is 3
